@@ -41,12 +41,15 @@ class ConfigTest(CoverageTest):
 
     def test_config_file(self) -> None:
         # A .coveragerc file will be read into the configuration.
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             # This is just a bogus .rc file for testing.
             [run]
             timid =         True
             data_file =     .hello_kitty.data
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         assert cov.config.timid
         assert not cov.config.branch
@@ -55,12 +58,15 @@ class ConfigTest(CoverageTest):
     @pytest.mark.parametrize("file_class", FilePathClasses)
     def test_named_config_file(self, file_class: FilePathType) -> None:
         # You can name the config file what you like.
-        self.make_file("my_cov.ini", """\
+        self.make_file(
+            "my_cov.ini",
+            """\
             [run]
             timid = True
             ; I wouldn't really use this as a data file...
             data_file = delete.me
-            """)
+            """,
+        )
         cov = coverage.Coverage(config_file=file_class("my_cov.ini"))
         assert cov.config.timid
         assert not cov.config.branch
@@ -68,7 +74,9 @@ class ConfigTest(CoverageTest):
 
     def test_toml_config_file(self) -> None:
         # A pyproject.toml file will be read into the configuration.
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             # This is just a bogus toml file for testing.
             [tool.somethingelse]
             authors = ["Joe D'Ávila <joe@gmail.com>"]
@@ -84,7 +92,8 @@ class ConfigTest(CoverageTest):
             title = "tabblo & «ταБЬℓσ»"
             [tool.coverage.plugins.a_plugin]
             hello = "world"
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         assert cov.config.timid
         assert not cov.config.branch
@@ -98,22 +107,28 @@ class ConfigTest(CoverageTest):
 
     def test_toml_ints_can_be_floats(self) -> None:
         # Test that our class doesn't reject integers when loading floats
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             # This is just a bogus toml file for testing.
             [tool.coverage.report]
             fail_under = 90
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         assert cov.config.fail_under == 90
         assert isinstance(cov.config.fail_under, float)
 
     def test_ignored_config_file(self) -> None:
         # You can disable reading the .coveragerc file.
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             timid = True
             data_file = delete.me
-            """)
+            """,
+        )
         cov = coverage.Coverage(config_file=False)
         assert not cov.config.timid
         assert not cov.config.branch
@@ -121,11 +136,14 @@ class ConfigTest(CoverageTest):
 
     def test_config_file_then_args(self) -> None:
         # The arguments override the .coveragerc file.
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             timid = True
             data_file = weirdo.file
-            """)
+            """,
+        )
         cov = coverage.Coverage(timid=False, data_file=".mycov")
         assert not cov.config.timid
         assert not cov.config.branch
@@ -133,11 +151,14 @@ class ConfigTest(CoverageTest):
 
     def test_data_file_from_environment(self) -> None:
         # There's an environment variable for the data_file.
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             timid = True
             data_file = weirdo.file
-            """)
+            """,
+        )
         self.set_environ("COVERAGE_FILE", "fromenv.dat")
         cov = coverage.Coverage()
         assert cov.config.data_file == "fromenv.dat"
@@ -146,19 +167,25 @@ class ConfigTest(CoverageTest):
         assert cov.config.data_file == "fromarg.dat"
 
     def test_debug_from_environment(self) -> None:
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             debug = dataio, pids
-            """)
+            """,
+        )
         self.set_environ("COVERAGE_DEBUG", "callers, fooey")
         cov = coverage.Coverage()
         assert cov.config.debug == ["dataio", "pids", "callers", "fooey"]
 
     def test_rcfile_from_environment(self) -> None:
-        self.make_file("here.ini", """\
+        self.make_file(
+            "here.ini",
+            """\
             [run]
             data_file = overthere.dat
-            """)
+            """,
+        )
         self.set_environ("COVERAGE_RCFILE", "here.ini")
         cov = coverage.Coverage()
         assert cov.config.data_file == "overthere.dat"
@@ -171,14 +198,20 @@ class ConfigTest(CoverageTest):
 
     @pytest.mark.parametrize("force", [False, True])
     def test_force_environment(self, force: bool) -> None:
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             debug = dataio, pids
-            """)
-        self.make_file("force.ini", """\
+            """,
+        )
+        self.make_file(
+            "force.ini",
+            """\
             [run]
             debug = callers, fooey
-            """)
+            """,
+        )
         if force:
             self.set_environ("COVERAGE_FORCE_CONFIG", "force.ini")
         cov = coverage.Coverage()
@@ -187,44 +220,82 @@ class ConfigTest(CoverageTest):
         else:
             assert cov.config.debug == ["dataio", "pids"]
 
-    @pytest.mark.parametrize("bad_config, msg", [
-        ("[run]\ntimid = maybe?\n", r"maybe[?]"),
-        ("timid = 1\n", r"no section headers"),
-        ("[run\n", r"\[run"),
-        ("[report]\nexclude_lines = foo(\n",
-            r"Invalid \[report\].exclude_lines value 'foo\(': " +
-            r"(unbalanced parenthesis|missing \))"),
-        ("[report]\npartial_branches = foo[\n",
-            r"Invalid \[report\].partial_branches value 'foo\[': " +
-            r"(unexpected end of regular expression|unterminated character set)"),
-        ("[report]\npartial_branches_always = foo***\n",
-            r"Invalid \[report\].partial_branches_always value " +
-            r"'foo\*\*\*': " +
-            r"multiple repeat"),
-    ])
+    @pytest.mark.parametrize(
+        "bad_config, msg",
+        [
+            ("[run]\ntimid = maybe?\n", r"maybe[?]"),
+            ("timid = 1\n", r"no section headers"),
+            ("[run\n", r"\[run"),
+            (
+                "[report]\nexclude_lines = foo(\n",
+                r"Invalid \[report\].exclude_lines value 'foo\(': "
+                + r"(unbalanced parenthesis|missing \))",
+            ),
+            (
+                "[report]\nexclude_also = foo(\n",
+                r"Invalid \[report\].exclude_also value 'foo\(': "
+                + r"(unbalanced parenthesis|missing \))",
+            ),
+            (
+                "[report]\npartial_branches = foo[\n",
+                r"Invalid \[report\].partial_branches value 'foo\[': "
+                + r"(unexpected end of regular expression|unterminated character set)",
+            ),
+            (
+                "[report]\npartial_also = foo[\n",
+                r"Invalid \[report\].partial_also value 'foo\[': "
+                + r"(unexpected end of regular expression|unterminated character set)",
+            ),
+            (
+                "[report]\npartial_branches_always = foo***\n",
+                r"Invalid \[report\].partial_branches_always value "
+                + r"'foo\*\*\*': "
+                + r"multiple repeat",
+            ),
+        ],
+    )
     def test_parse_errors(self, bad_config: str, msg: str) -> None:
         # Im-parsable values raise ConfigError, with details.
         self.make_file(".coveragerc", bad_config)
         with pytest.raises(ConfigError, match=msg):
             coverage.Coverage()
 
-    @pytest.mark.parametrize("bad_config, msg", [
-        ("[tool.coverage.run]\ntimid = \"maybe?\"\n", r"maybe[?]"),
-        ("[tool.coverage.run\n", None),
-        ('[tool.coverage.report]\nexclude_lines = ["foo("]\n',
-         r"Invalid \[tool.coverage.report\].exclude_lines value 'foo\(': " +
-         r"(unbalanced parenthesis|missing \))"),
-        ('[tool.coverage.report]\npartial_branches = ["foo["]\n',
-         r"Invalid \[tool.coverage.report\].partial_branches value 'foo\[': " +
-         r"(unexpected end of regular expression|unterminated character set)"),
-        ('[tool.coverage.report]\npartial_branches_always = ["foo***"]\n',
-         r"Invalid \[tool.coverage.report\].partial_branches_always value " +
-         r"'foo\*\*\*': " +
-         r"multiple repeat"),
-        ('[tool.coverage.run]\nconcurrency="foo"', "not a list"),
-        ("[tool.coverage.report]\nprecision=1.23", "not an integer"),
-        ('[tool.coverage.report]\nfail_under="s"', "couldn't convert to a float"),
-    ])
+    @pytest.mark.parametrize(
+        "bad_config, msg",
+        [
+            ('[tool.coverage.run]\ntimid = "maybe?"\n', r"maybe[?]"),
+            ("[tool.coverage.run\n", None),
+            (
+                '[tool.coverage.report]\nexclude_lines = ["foo("]\n',
+                r"Invalid \[tool.coverage.report\].exclude_lines value 'foo\(': "
+                + r"(unbalanced parenthesis|missing \))",
+            ),
+            (
+                '[tool.coverage.report]\nexclude_also = ["foo("]\n',
+                r"Invalid \[tool.coverage.report\].exclude_also value 'foo\(': "
+                + r"(unbalanced parenthesis|missing \))",
+            ),
+            (
+                '[tool.coverage.report]\npartial_branches = ["foo["]\n',
+                r"Invalid \[tool.coverage.report\].partial_branches value 'foo\[': "
+                + r"(unexpected end of regular expression|unterminated character set)",
+            ),
+            (
+                '[tool.coverage.report]\npartial_also = ["foo["]\n',
+                r"Invalid \[tool.coverage.report\].partial_also value 'foo\[': "
+                + r"(unexpected end of regular expression|unterminated character set)",
+            ),
+            (
+                '[tool.coverage.report]\npartial_branches_always = ["foo***"]\n',
+                r"Invalid \[tool.coverage.report\].partial_branches_always value "
+                + r"'foo\*\*\*': "
+                + r"multiple repeat",
+            ),
+            ('[tool.coverage.run]\nconcurrency="foo"', "not a list"),
+            ("[tool.coverage.report]\nprecision=1.23", "not an integer"),
+            ('[tool.coverage.report]\nfail_under="s"', "couldn't convert to a float"),
+        ],
+    )
     def test_toml_parse_errors(self, bad_config: str, msg: str) -> None:
         # Im-parsable values raise ConfigError, with details.
         self.make_file("pyproject.toml", bad_config)
@@ -233,7 +304,9 @@ class ConfigTest(CoverageTest):
 
     def test_environment_vars_in_config(self) -> None:
         # Config files can have $envvars in them.
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             data_file = $DATA_FILE.fooey
             branch = $OKAY
@@ -244,7 +317,8 @@ class ConfigTest(CoverageTest):
                 x${THING}y
                 x${NOTHING}y
                 huh$${X}what
-            """)
+            """,
+        )
         self.set_environ("DATA_FILE", "hello-world")
         self.set_environ("THING", "ZZZ")
         self.set_environ("OKAY", "yes")
@@ -255,7 +329,9 @@ class ConfigTest(CoverageTest):
 
     def test_environment_vars_in_toml_config(self) -> None:
         # Config files can have $envvars in them.
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             [tool.coverage.run]
             data_file = "$DATA_FILE.fooey"
             branch = "$BRANCH"
@@ -273,7 +349,8 @@ class ConfigTest(CoverageTest):
             # This reproduces the failure from https://github.com/nedbat/coveragepy/issues/1481
             # When OTHER has a backslash that isn't a valid escape, like \\z (see below).
             something = "if [ $OTHER ]; then printf '%s\\n' 'Hi'; fi"
-            """)
+            """,
+        )
         self.set_environ("BRANCH", "true")
         self.set_environ("DIGITS", "3")
         self.set_environ("FAIL_UNDER", "90.5")
@@ -288,13 +365,21 @@ class ConfigTest(CoverageTest):
 
     def test_tilde_in_config(self) -> None:
         # Config entries that are file paths can be tilde-expanded.
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             data_file = ~/data.file
 
             [html]
             directory = ~joe/html_dir
 
+            [json]
+            output = ~/json/output.json
+
+            [lcov]
+            output = ~/lcov/~foo.lcov
+
             [xml]
             output = ~/somewhere/xml.out
 
@@ -308,34 +393,28 @@ class ConfigTest(CoverageTest):
             mapping =
                 ~/src
                 ~joe/source
-            """)
-        def expanduser(s: str) -> str:
-            """Fake tilde expansion"""
-            s = s.replace("~/", "/Users/me/")
-            s = s.replace("~joe/", "/Users/joe/")
-            return s
+            """,
+        )
 
-        with mock.patch.object(
-            coverage.config.os.path,  # type: ignore[attr-defined]
-            'expanduser',
-            new=expanduser
-        ):
-            cov = coverage.Coverage()
-        assert cov.config.data_file == "/Users/me/data.file"
-        assert cov.config.html_dir == "/Users/joe/html_dir"
-        assert cov.config.xml_output == "/Users/me/somewhere/xml.out"
-        assert cov.config.exclude_list == ["~/data.file", "~joe/html_dir"]
-        assert cov.config.paths == {'mapping': ['/Users/me/src', '/Users/joe/source']}
+        self.assert_tilde_results()
 
     def test_tilde_in_toml_config(self) -> None:
         # Config entries that are file paths can be tilde-expanded.
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             [tool.coverage.run]
             data_file = "~/data.file"
 
             [tool.coverage.html]
             directory = "~joe/html_dir"
 
+            [tool.coverage.json]
+            output = "~/json/output.json"
+
+            [tool.coverage.lcov]
+            output = "~/lcov/~foo.lcov"
+
             [tool.coverage.xml]
             output = "~/somewhere/xml.out"
 
@@ -351,7 +430,14 @@ class ConfigTest(CoverageTest):
                 "~/src",
                 "~joe/source",
             ]
-            """)
+            """,
+        )
+
+        self.assert_tilde_results()
+
+    def assert_tilde_results(self) -> None:
+        """Common assertions for two tilde tests."""
+
         def expanduser(s: str) -> str:
             """Fake tilde expansion"""
             s = s.replace("~/", "/Users/me/")
@@ -359,16 +445,18 @@ class ConfigTest(CoverageTest):
             return s
 
         with mock.patch.object(
-            coverage.config.os.path, # type: ignore[attr-defined]
-            'expanduser',
-            new=expanduser
+            coverage.config.os.path,  # type: ignore[attr-defined]
+            "expanduser",
+            new=expanduser,
         ):
             cov = coverage.Coverage()
         assert cov.config.data_file == "/Users/me/data.file"
         assert cov.config.html_dir == "/Users/joe/html_dir"
+        assert cov.config.json_output == "/Users/me/json/output.json"
+        assert cov.config.lcov_output == "/Users/me/lcov/~foo.lcov"
         assert cov.config.xml_output == "/Users/me/somewhere/xml.out"
         assert cov.config.exclude_list == ["~/data.file", "~joe/html_dir"]
-        assert cov.config.paths == {'mapping': ['/Users/me/src', '/Users/joe/source']}
+        assert cov.config.paths == {"mapping": ["/Users/me/src", "/Users/joe/source"]}
 
     def test_tweaks_after_constructor(self) -> None:
         # set_option can be used after construction to affect the config.
@@ -384,7 +472,9 @@ class ConfigTest(CoverageTest):
         assert cov.get_option("run:data_file") == "fooey.dat"
 
     def test_tweaks_paths_after_constructor(self) -> None:
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [paths]
             first =
                 /first/1
@@ -393,7 +483,8 @@ class ConfigTest(CoverageTest):
             second =
                 /second/a
                 /second/b
-            """)
+            """,
+        )
         old_paths = {
             "first": ["/first/1", "/first/2"],
             "second": ["/second/a", "/second/b"],
@@ -436,46 +527,77 @@ class ConfigTest(CoverageTest):
             _ = cov.get_option("no_such.plugin:foo")
 
     def test_unknown_option(self) -> None:
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             xyzzy = 17
-            """)
+            """,
+        )
         msg = r"Unrecognized option '\[run\] xyzzy=' in config file .coveragerc"
         with pytest.warns(CoverageWarning, match=msg):
             _ = coverage.Coverage()
 
     def test_unknown_option_toml(self) -> None:
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             [tool.coverage.run]
             xyzzy = 17
-            """)
+            """,
+        )
         msg = r"Unrecognized option '\[tool.coverage.run\] xyzzy=' in config file pyproject.toml"
         with pytest.warns(CoverageWarning, match=msg):
             _ = coverage.Coverage()
 
+    def test_unknown_patch(self) -> None:
+        self.make_file("foo.py", "a = 1")
+        self.make_file(
+            ".coveragerc",
+            """\
+            [run]
+            patch =
+                _exit
+                xyzzy
+            """,
+        )
+        msg = "Unknown patch 'xyzzy'"
+        with pytest.raises(ConfigError, match=msg):
+            cov = coverage.Coverage()
+            self.start_import_stop(cov, "foo")
+
     def test_misplaced_option(self) -> None:
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [report]
             branch = True
-            """)
+            """,
+        )
         msg = r"Unrecognized option '\[report\] branch=' in config file .coveragerc"
         with pytest.warns(CoverageWarning, match=msg):
             _ = coverage.Coverage()
 
     def test_unknown_option_in_other_ini_file(self) -> None:
-        self.make_file("setup.cfg", """\
+        self.make_file(
+            "setup.cfg",
+            """\
             [coverage:run]
             huh = what?
-            """)
+            """,
+        )
         msg = r"Unrecognized option '\[coverage:run\] huh=' in config file setup.cfg"
         with pytest.warns(CoverageWarning, match=msg):
             _ = coverage.Coverage()
 
     def test_exceptions_from_missing_things(self) -> None:
-        self.make_file("config.ini", """\
+        self.make_file(
+            "config.ini",
+            """\
             [run]
             branch = True
-            """)
+            """,
+        )
         config = HandyConfigParser(True)
         config.read(["config.ini"])
         with pytest.raises(ConfigError, match="No section: 'xyzzy'"):
@@ -484,15 +606,31 @@ class ConfigTest(CoverageTest):
             config.get("xyzzy", "foo")
 
     def test_exclude_also(self) -> None:
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             [tool.coverage.report]
             exclude_also = ["foobar", "raise .*Error"]
-            """)
+            """,
+        )
         cov = coverage.Coverage()
 
         expected = coverage.config.DEFAULT_EXCLUDE + ["foobar", "raise .*Error"]
         assert cov.config.exclude_list == expected
 
+    def test_partial_also(self) -> None:
+        self.make_file(
+            "pyproject.toml",
+            """\
+            [tool.coverage.report]
+            partial_also = ["foobar", "raise .*Error"]
+            """,
+        )
+        cov = coverage.Coverage()
+
+        expected = coverage.config.DEFAULT_PARTIAL + ["foobar", "raise .*Error"]
+        assert cov.config.partial_list == expected
+
     def test_core_option(self) -> None:
         # Test that the core option can be set in the configuration file.
         self.del_environ("COVERAGE_CORE")
@@ -500,18 +638,24 @@ class ConfigTest(CoverageTest):
         default_core = cov.config.core
         core_to_set = "ctrace" if default_core == "pytrace" else "pytrace"
 
-        self.make_file(".coveragerc", f"""\
+        self.make_file(
+            ".coveragerc",
+            f"""\
             [run]
             core = {core_to_set}
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         assert cov.config.core == core_to_set
         os.remove(".coveragerc")
 
-        self.make_file("pyproject.toml", f"""\
+        self.make_file(
+            "pyproject.toml",
+            f"""\
             [tool.coverage.run]
             core = "{core_to_set}"
-            """)
+            """,
+        )
 
         cov = coverage.Coverage()
         assert cov.config.core == core_to_set
@@ -654,13 +798,13 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         assert cov.config.xml_package_depth == 17
 
         assert cov.config.paths == {
-            'source': ['.', '/home/ned/src/'],
-            'other': ['other', '/home/ned/other', 'c:\\Ned\\etc'],
+            "source": [".", "/home/ned/src/"],
+            "other": ["other", "/home/ned/other", "c:\\Ned\\etc"],
         }
 
         assert cov.config.get_plugin_options("plugins.a_plugin") == {
-            'hello': 'world',
-            'names': 'Jane/John/Jenny',
+            "hello": "world",
+            "names": "Jane/John/Jenny",
         }
         assert cov.config.get_plugin_options("plugins.another") == {}
         assert cov.config.json_show_contexts is True
@@ -700,15 +844,21 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
 
     def check_other_not_read_if_coveragerc(self, fname: str) -> None:
         """Check config `fname` is not read if .coveragerc exists."""
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [run]
             include = foo
-            """)
-        self.make_file(fname, """\
+            """,
+        )
+        self.make_file(
+            fname,
+            """\
             [coverage:run]
             omit = bar
             branch = true
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         assert cov.config.run_include == ["foo"]
         assert cov.config.run_omit == []
@@ -722,11 +872,14 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
 
     def check_other_config_need_prefixes(self, fname: str) -> None:
         """Check that `fname` sections won't be read if un-prefixed."""
-        self.make_file(fname, """\
+        self.make_file(
+            fname,
+            """\
             [run]
             omit = bar
             branch = true
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         assert cov.config.run_omit == []
         assert cov.config.branch is False
@@ -754,7 +907,9 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
         self.assert_config_settings_are_correct(cov)
 
     def test_non_ascii(self) -> None:
-        self.make_file(".coveragerc", """\
+        self.make_file(
+            ".coveragerc",
+            """\
             [report]
             exclude_lines =
                 first
@@ -762,7 +917,8 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
                 third
             [html]
             title = tabblo & «ταБЬℓσ» # numbers
-            """)
+            """,
+        )
         self.set_environ("TOX_ENVNAME", "weirdo")
         cov = coverage.Coverage()
 
@@ -802,11 +958,14 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
     @pytest.mark.skipif(env.PYVERSION >= (3, 11), reason="Python 3.11 has toml in stdlib")
     def test_no_toml_installed_pyproject_toml(self) -> None:
         # Can't have coverage config in pyproject.toml without toml installed.
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             # A toml file!
             [tool.coverage.run]
             xyzzy = 17
-            """)
+            """,
+        )
         with mock.patch.object(coverage.tomlconfig, "has_tomllib", False):
             msg = "Can't read 'pyproject.toml' without TOML support"
             with pytest.raises(ConfigError, match=msg):
@@ -815,11 +974,14 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
     @pytest.mark.skipif(env.PYVERSION >= (3, 11), reason="Python 3.11 has toml in stdlib")
     def test_no_toml_installed_pyproject_toml_shorter_syntax(self) -> None:
         # Can't have coverage config in pyproject.toml without toml installed.
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             # A toml file!
             [tool.coverage]
             run.parallel = true
-            """)
+            """,
+        )
         with mock.patch.object(coverage.tomlconfig, "has_tomllib", False):
             msg = "Can't read 'pyproject.toml' without TOML support"
             with pytest.raises(ConfigError, match=msg):
@@ -828,11 +990,14 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
     @pytest.mark.skipif(env.PYVERSION >= (3, 11), reason="Python 3.11 has toml in stdlib")
     def test_no_toml_installed_pyproject_no_coverage(self) -> None:
         # It's ok to have non-coverage pyproject.toml without toml installed.
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             # A toml file!
             [tool.something]
             xyzzy = 17
-            """)
+            """,
+        )
         with mock.patch.object(coverage.tomlconfig, "has_tomllib", False):
             cov = coverage.Coverage()
             # We get default settings:
@@ -841,10 +1006,13 @@ class ConfigFileTest(UsingModulesMixin, CoverageTest):
             assert cov.config.data_file == ".coverage"
 
     def test_exceptions_from_missing_toml_things(self) -> None:
-        self.make_file("pyproject.toml", """\
+        self.make_file(
+            "pyproject.toml",
+            """\
             [tool.coverage.run]
             branch = true
-            """)
+            """,
+        )
         config = TomlConfigParser(False)
         config.read("pyproject.toml")
         with pytest.raises(ConfigError, match="No section: 'xyzzy'"):
